package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletPlatformFlow;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 挂载操作流程Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-14
 */
public interface PlayletPlatformFlowMapper extends BaseMapper<PlayletPlatformFlow>
{
    /**
     * 查询挂载操作流程
     *
     * @param id 挂载操作流程主键
     * @return 挂载操作流程
     */
    public PlayletPlatformFlow selectPlayletPlatformFlowById(Long id);

    /**
     * 查询挂载操作流程列表
     *
     * @param playletPlatformFlow 挂载操作流程
     * @return 挂载操作流程集合
     */
    public List<PlayletPlatformFlow> selectPlayletPlatformFlowList(PlayletPlatformFlow playletPlatformFlow);

    /**
     * 新增挂载操作流程
     *
     * @param playletPlatformFlow 挂载操作流程
     * @return 结果
     */
    public int insertPlayletPlatformFlow(PlayletPlatformFlow playletPlatformFlow);

    /**
     * 修改挂载操作流程
     *
     * @param playletPlatformFlow 挂载操作流程
     * @return 结果
     */
    public int updatePlayletPlatformFlow(PlayletPlatformFlow playletPlatformFlow);

    /**
     * 删除挂载操作流程
     *
     * @param id 挂载操作流程主键
     * @return 结果
     */
    public int deletePlayletPlatformFlowById(Long id);

    /**
     * 批量删除挂载操作流程
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletPlatformFlowByIds(String[] ids);
}
